@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.1.1'
+    version = '1.1.2'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -61,7 +61,7 @@ class DingDingPlugin(NotificationPlugin):
 
         count = self.getGroupCount(group.id)
 
-        if(count>2):
+        if(int(count)>2):
             return
         
 
